@@ -1,14 +1,14 @@
 /* © 2008 David Given.
- * WordGrinder is licensed under the BSD open source license. See the COPYING
+ * WordGrinder is licensed under the MIT open source license. See the COPYING
  * file in this distribution for the full text.
  *
- * $Id: dpy.c 121 2008-09-07 15:35:27Z dtrg $
+ * $Id: dpy.c 159 2009-12-13 13:11:03Z dtrg $
  * $URL: https://wordgrinder.svn.sf.net/svnroot/wordgrinder/wordgrinder/src/c/arch/unix/cursesw/dpy.c $
  */
 
 #include "globals.h"
 #include <string.h>
-#include <ncursesw/curses.h>
+#include <curses.h>
 #include <wctype.h>
 #include <sys/time.h>
 #include <time.h>
