@@ -1,8 +1,8 @@
 -- © 2008 David Given.
--- WordGrinder is licensed under the BSD open source license. See the COPYING
+-- WordGrinder is licensed under the MIT open source license. See the COPYING
 -- file in this distribution for the full text.
 --
--- $Id: document.lua 121 2008-09-07 15:35:27Z dtrg $
+-- $Id: document.lua 159 2009-12-13 13:11:03Z dtrg $
 -- $URL: https://wordgrinder.svn.sf.net/svnroot/wordgrinder/wordgrinder/src/lua/document.lua $
 
 local table_remove = table.remove
@@ -569,6 +569,22 @@ local function create_styles()
 			indent = 4,
 			above = 0,
 			below = 0
+		},
+		{
+			desc = "Preformatted text",
+			name = "PRE",
+			html = "PRE",
+			indent = 4,
+			above = 0,
+			below = 0
+		},
+		{
+			desc = "Raw data exported to output file",
+			name = "RAW",
+			html = nil,
+			indent = 0,
+			above = 0,
+			below = 0
 		}
 	}
 	
