@@ -1,8 +1,8 @@
 -- © 2008 David Given.
--- WordGrinder is licensed under the BSD open source license. See the COPYING
+-- WordGrinder is licensed under the MIT open source license. See the COPYING
 -- file in this distribution for the full text.
 --
--- $Id: export.lua 121 2008-09-07 15:35:27Z dtrg $
+-- $Id: export.lua 159 2009-12-13 13:11:03Z dtrg $
 -- $URL: https://wordgrinder.svn.sf.net/svnroot/wordgrinder/wordgrinder/src/lua/export.lua $
 
 local ITALIC = wg.ITALIC
@@ -21,15 +21,24 @@ function ExportFileUsingCallbacks(document, cb)
 	cb.prologue()
 	
 	local listmode = false
+	local rawmode = false
 	local italic, underline
 	local olditalic, oldunderline
 	local firstword
 	local wordbreak
+	local emptyword
 	
 	local wordwriter = function (style, text)
 		italic = bit(style, ITALIC)
 		underline = bit(style, UNDERLINE)
 		
+		local writer
+		if rawmode then
+			writer = cb.rawtext
+		else
+			writer = cb.text
+		end
+		
 		if not italic and olditalic then
 			cb.italic_off()
 		end
@@ -38,7 +47,7 @@ function ExportFileUsingCallbacks(document, cb)
 		end
 		
 		if wordbreak then
-			cb.text(' ')
+			writer(' ')
 			wordbreak = false
 		end
 	
@@ -48,8 +57,9 @@ function ExportFileUsingCallbacks(document, cb)
 		if italic and not olditalic then
 			cb.italic_on()
 		end
-		cb.text(text)
-		
+		writer(text)
+
+		emptyword = false
 		olditalic = italic
 		oldunderline = underline
 	end
@@ -65,11 +75,15 @@ function ExportFileUsingCallbacks(document, cb)
 			cb.list_end()
 			listmode = false
 		end
-			
+		
+		rawmode = (style.name == "RAW")
+		
 		cb.paragraph_start(style.name)
 	
 		if (#paragraph == 1) and (#paragraph[1].text == 0) then
-			cb.notext()
+			if rawmode then
+				cb.notext()
+			end
 		else
 			firstword = true
 			wordbreak = false	
@@ -83,9 +97,13 @@ function ExportFileUsingCallbacks(document, cb)
 					wordbreak = true
 				end
 				
+				emptyword = true
 				italic = false
 				underline = false
 				ParseWord(word.text, 0, wordwriter) -- FIXME
+				if emptyword then
+					wordwriter(0, "")
+				end
 			end
 			if italic then
 				cb.italic_off()
