@@ -1,8 +1,8 @@
 -- © 2008 David Given.
--- WordGrinder is licensed under the BSD open source license. See the COPYING
+-- WordGrinder is licensed under the MIT open source license. See the COPYING
 -- file in this distribution for the full text.
 --
--- $Id: menu.lua 121 2008-09-07 15:35:27Z dtrg $
+-- $Id: menu.lua 159 2009-12-13 13:11:03Z dtrg $
 -- $URL: https://wordgrinder.svn.sf.net/svnroot/wordgrinder/wordgrinder/src/lua/menu.lua $
 
 local Write = wg.write
@@ -97,6 +97,7 @@ local SettingsMenu = addmenu("Settings",
 {
     {"FSautosave", "A", "Autosave...",               nil,         Cmd.ConfigureAutosave},
     {"FSscrapbook", "S", "Scrapbook...",             nil,         Cmd.ConfigureScrapbook},
+    {"FHTMLExport", "H", "HTML export...",           nil,         Cmd.ConfigureHTMLExport},
 })
 
 local FileMenu = addmenu("File",
@@ -406,7 +407,14 @@ function RebuildParagraphStylesMenu(styles)
 	local m = {}
 	
 	for id, style in ipairs(styles) do
-		m[#m+1] = {"SP"..id, tostring(id-1), style.name..": "..style.desc, nil,
+		local shortcut
+		if (id <= 10) then
+			shortcut = tostring(id - 1)
+		else
+			shortcut = string.char(id + 54)
+		end
+		
+		m[#m+1] = {"SP"..id, shortcut, style.name..": "..style.desc, nil,
 			function()
 				Cmd.ChangeParagraphStyle(style.name)
 			end}
